@@ -8,17 +8,17 @@ Zeev Tarantov <zeev.tarantov@gmail.com>
 extern "C" {
 #endif
 
-#define CSNAPPY_VERSION	2
+#define CSNAPPY_VERSION	4
 
-#define SNAPPY_WORKMEM_BYTES_POWER_OF_TWO 15
-#define SNAPPY_WORKMEM_BYTES (1 << SNAPPY_WORKMEM_BYTES_POWER_OF_TWO)
+#define CSNAPPY_WORKMEM_BYTES_POWER_OF_TWO 15
+#define CSNAPPY_WORKMEM_BYTES (1 << CSNAPPY_WORKMEM_BYTES_POWER_OF_TWO)
 
 /*
  * Returns the maximal size of the compressed representation of
  * input data that is "source_len" bytes in length;
  */
 uint32_t
-snappy_max_compressed_length(uint32_t source_len) __attribute__((const));
+csnappy_max_compressed_length(uint32_t source_len) __attribute__((const));
 
 /*
  * Flat array compression that does not emit the "uncompressed length"
@@ -26,7 +26,7 @@ snappy_max_compressed_length(uint32_t source_len) __attribute__((const));
  *
  * REQUIRES: "input" is at most 32KiB long.
  * REQUIRES: "output" points to an array of memory that is at least
- * "snappy_max_compressed_length(input_length)" in size.
+ * "csnappy_max_compressed_length(input_length)" in size.
  * REQUIRES: working_memory has (1 << workmem_bytes_power_of_two) bytes.
  * REQUIRES: 9 <= workmem_bytes_power_of_two <= 15.
  *
@@ -34,7 +34,7 @@ snappy_max_compressed_length(uint32_t source_len) __attribute__((const));
  * "end - output" is the compressed size of "input".
  */
 char*
-snappy_compress_fragment(
+csnappy_compress_fragment(
 	const char* input,
 	const uint32_t input_length,
 	char *output,
@@ -43,7 +43,7 @@ snappy_compress_fragment(
 
 /*
  * REQUIRES: "compressed" must point to an area of memory that is at
- * least "snappy_max_compressed_length(input_length)" bytes in length.
+ * least "csnappy_max_compressed_length(input_length)" bytes in length.
  * REQUIRES: working_memory has (1 << workmem_bytes_power_of_two) bytes.
  * REQUIRES: 9 <= workmem_bytes_power_of_two <= 15.
  *
@@ -53,7 +53,7 @@ snappy_compress_fragment(
  * "*out_compressed_length" is set to the length of the compressed output.
  */
 void
-snappy_compress(
+csnappy_compress(
 	const char *input,
 	uint32_t input_length,
 	char *compressed,
@@ -66,45 +66,45 @@ snappy_compress(
  * REQUIRES: start points to compressed data.
  * REQUIRES: n is length of available compressed data.
  * 
- * Returns SNAPPY_E_OK iff was able to decode length.
+ * Returns a number above 0 for success and below 0 for error.
  * Stores decoded length into *result.
  */
 int
-snappy_get_uncompressed_length(const char *start, uint32_t n, uint32_t *result);
+csnappy_get_uncompressed_length(const char *start, uint32_t n, uint32_t *result);
 
 /*
  * Safely decompresses all data from array "src" of length "src_len" containing
  * entire compressed stream (with header) into array "dst" of size "dst_len".
- * REQUIRES: dst_len is at least snappy_get_uncompressed_length(...).
+ * REQUIRES: dst_len is at least csnappy_get_uncompressed_length(...).
  * 
- * Iff sucessful, returns SNAPPY_E_OK.
+ * Iff sucessful, returns CSNAPPY_E_OK.
  * If recorded length in header is greater than dst_len, returns
- *  SNAPPY_E_OUTPUT_INSUF.
+ *  CSNAPPY_E_OUTPUT_INSUF.
  * If compressed data is malformed, does not write more than dst_len into dst.
  */
 int
-snappy_decompress(const char *src, uint32_t src_len, char *dst, uint32_t dst_len);
+csnappy_decompress(const char *src, uint32_t src_len, char *dst, uint32_t dst_len);
 
 /*
  * Safely decompresses stream src_len bytes long read from src to dst.
- * Maximum available space at dst must be provided in *dst_len by caller.
+ * Amount of available space at dst must be provided in *dst_len by caller.
  * If compressed stream needs more space, it will not overflow and return
- *  SNAPPY_E_OUTPUT_OVERRUN.
+ *  CSNAPPY_E_OUTPUT_OVERRUN.
  * On success, sets *dst_len to actal number of bytes decompressed.
- * Iff sucessful, returns SNAPPY_E_OK.
+ * Iff sucessful, returns CSNAPPY_E_OK.
  */
 int
-snappy_decompress_noheader(const char *src, uint32_t src_len, char *dst, uint32_t *dst_len);
+csnappy_decompress_noheader(const char *src, uint32_t src_len, char *dst, uint32_t *dst_len);
 
 /*
  * Return values (< 0 = Error)
  */
-#define SNAPPY_E_OK			0
-#define SNAPPY_E_HEADER_BAD		(-1)
-#define SNAPPY_E_OUTPUT_INSUF		(-2)
-#define SNAPPY_E_OUTPUT_OVERRUN		(-3)
-#define SNAPPY_E_INPUT_NOT_CONSUMED	(-4)
-#define SNAPPY_E_DATA_MALFORMED		(-5)
+#define CSNAPPY_E_OK			0
+#define CSNAPPY_E_HEADER_BAD		(-1)
+#define CSNAPPY_E_OUTPUT_INSUF		(-2)
+#define CSNAPPY_E_OUTPUT_OVERRUN	(-3)
+#define CSNAPPY_E_INPUT_NOT_CONSUMED	(-4)
+#define CSNAPPY_E_DATA_MALFORMED	(-5)
 
 #ifdef __cplusplus
 }
